@@ -77,13 +77,13 @@ from collections import defaultdict
 
 import docopt
 import yamlconf
-from sklearn import grid_search
+from sklearn.model_selection import ParameterGrid
 from tabulate import tabulate
 
+from . import util
 from ..about import __version__
 from ..dependencies import solve
 from ..scoring.models import util as model_util
-from . import util
 from .util import Timeout, read_observations
 
 logger = logging.getLogger(__name__)
@@ -264,7 +264,7 @@ def _model_param_grid(params_config):
                         .format(config['class']))
             continue
 
-        param_grid = grid_search.ParameterGrid(config['params'])
+        param_grid = ParameterGrid(config['params'])
 
         yield name, Model, param_grid
 
